:py:mod:`piel.models.frequency.photonic.directional_coupler_real`
=================================================================

.. py:module:: piel.models.frequency.photonic.directional_coupler_real

.. autoapi-nested-parse::

   Translated from https://github.com/flaport/sax or https://github.com/flaport/photontorch/tree/master
